==> leoo_junpro-1.0.1.tar.gz: lib/leooimpjunpro/leoolistjunpro/leoovideolistjunpro.dart <==
import 'package:flutter/material.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoodaojunpro/leoomaindaojunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoovideolistentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leooindexjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leoomaineventjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leooinfojunpro/leoovideoplayjunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

///小视频播放界面-首页
class LeooVideoListJunPro extends StatefulWidget {
  static bool leooOpenJunPro = false;
  static int leooIndexJunPro = 0;
  final int type;
  final int page;
  final int currentIndex;
  final List<LeooVideoListEntity> videoList;

  const LeooVideoListJunPro(
      this.type, this.page, this.currentIndex, this.videoList,
      {Key? key})
      : super(key: key);

  @override
  _LeooVideoListState createState() => _LeooVideoListState();
}

class _LeooVideoListState extends State<LeooVideoListJunPro>
    with WidgetsBindingObserver, RouteAware {
  late PageController _pageController;
  final RefreshController _refreshController = RefreshController();
  List<LeooVideoListEntity> videoList = [];
  int page = 1;

  @override
  void initState() {
    super.initState();
    LeooVideoListJunPro.leooOpenJunPro = true;
    LeooVideoListJunPro.leooIndexJunPro = widget.currentIndex;
    WidgetsBinding.instance?.addObserver(this);
    page = widget.page;
    videoList = widget.videoList;
    _pageController = PageController(initialPage: widget.currentIndex);
  }

  void getList() {
    LeooMainDaoJunPro.leooVideoListJunPro(widget.type, page).then((res) async {
      if (res.result) {
        if (page == 1) {
          videoList.clear();
        }
        videoList.addAll(res.data);
        LeooCodeUtilsJunPro.onSetState(this);
        if (page == 1) {
          _refreshController.refreshCompleted();
          _refreshController.loadComplete();
        } else if (res.data.isEmpty) {
          _refreshController.loadNoData();
        } else {
          _refreshController.loadComplete();
        }
      } else {
        if (page == 1) {
          _refreshController.refreshFailed();
        } else {
          _refreshController.loadFailed();
        }
        LeooCommonUtilsJunPro.leooShowErrorToastJunPro(res);
      }
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      eventBus
          .fire(LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
    });
  }

  @override
  void didPushNext() {
    super.didPushNext();
    eventBus.fire(LeooVideoPlayEventJunPro(-1));
  }

  @override
  void dispose() {
    LeooVideoListJunPro.leooOpenJunPro = false;
    WidgetsBinding.instance?.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        eventBus.fire(
            LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
      });
    } else if (state == AppLifecycleState.paused) {
      eventBus.fire(LeooVideoPlayEventJunPro(-1));
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: NotificationListener(
        onNotification: (ScrollNotification notification) {
          if (notification.depth == 0 &&
              notification is ScrollUpdateNotification) {
            final PageMetrics metrics = notification.metrics as PageMetrics;
            final int currentPage = metrics.page!.round();
            if (currentPage != LeooVideoListJunPro.leooIndexJunPro) {
              LeooVideoListJunPro.leooIndexJunPro = currentPage;
              eventBus.fire(LeooVideoPlayEventJunPro(currentPage));
            }
          }
          return false;
        },
        child: SmartRefresher(
          controller: _refreshController,
          header: const ClassicHeader(),
          footer: const ClassicFooter(),
          enablePullUp:
              videoList.length * 3 >= LeooAppConfigJunPro.leooPageSizeJunPro,
          onRefresh: () {
            page = 1;
            getList();
          },
          onLoading: () {
            page++;
            getList();
          },
          child: CustomScrollView(
            physics: const PageScrollPhysics(),
            controller: _pageController,
            slivers: <Widget>[
              SliverFillViewport(
                delegate:
                    SliverChildListDelegate(videoList.asMap().keys.map((index) {
                  return LeooVideoPlayJunPro(
                    index,
                    videoList[index],
                    play: index == LeooVideoListJunPro.leooIndexJunPro,
                    mine: widget.type == 3,
                  );
                }).toList()),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> leoo_junpro-2.0.0.tar.gz: lib/leooimpjunpro/leoolistjunpro/leoovideolistjunpro.dart <==
import 'package:flutter/material.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoodaojunpro/leoomaindaojunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoovideolistentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leooindexjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leoomaineventjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leooinfojunpro/leoovideoplayjunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

///小视频播放界面-首页
class LeooVideoListJunPro extends StatefulWidget {
  static bool leooOpenJunPro = false;
  static int leooIndexJunPro = 0;
  final int type;
  final int page;
  final int currentIndex;
  final List<LeooVideoListEntity> videoList;

  const LeooVideoListJunPro(
      this.type, this.page, this.currentIndex, this.videoList,
      {Key? key})
      : super(key: key);

  @override
  _LeooVideoListState createState() => _LeooVideoListState();
}

class _LeooVideoListState extends State<LeooVideoListJunPro>
    with WidgetsBindingObserver, RouteAware {
  late PageController _pageController;
  final RefreshController _refreshController = RefreshController();
  List<LeooVideoListEntity> videoList = [];
  int page = 1;

  @override
  void initState() {
    super.initState();
    LeooVideoListJunPro.leooOpenJunPro = true;
    LeooVideoListJunPro.leooIndexJunPro = widget.currentIndex;
    WidgetsBinding.instance.addObserver(this);
    page = widget.page;
    videoList = widget.videoList;
    _pageController = PageController(initialPage: widget.currentIndex);
  }

  void getList() {
    LeooMainDaoJunPro.leooVideoListJunPro(widget.type, page).then((res) async {
      if (res.result) {
        if (page == 1) {
          videoList.clear();
        }
        videoList.addAll(res.data);
        LeooCodeUtilsJunPro.onSetState(this);
        if (page == 1) {
          _refreshController.refreshCompleted();
          _refreshController.loadComplete();
        } else if (res.data.isEmpty) {
          _refreshController.loadNoData();
        } else {
          _refreshController.loadComplete();
        }
      } else {
        if (page == 1) {
          _refreshController.refreshFailed();
        } else {
          _refreshController.loadFailed();
        }
        LeooCommonUtilsJunPro.leooShowErrorToastJunPro(res);
      }
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      eventBus
          .fire(LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
    });
  }

  @override
  void didPushNext() {
    super.didPushNext();
    eventBus.fire(LeooVideoPlayEventJunPro(-1));
  }

  @override
  void dispose() {
    LeooVideoListJunPro.leooOpenJunPro = false;
    WidgetsBinding.instance.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        eventBus.fire(
            LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
      });
    } else if (state == AppLifecycleState.paused) {
      eventBus.fire(LeooVideoPlayEventJunPro(-1));
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: NotificationListener(
        onNotification: (ScrollNotification notification) {
          if (notification.depth == 0 &&
              notification is ScrollUpdateNotification) {
            final PageMetrics metrics = notification.metrics as PageMetrics;
            final int currentPage = metrics.page!.round();
            if (currentPage != LeooVideoListJunPro.leooIndexJunPro) {
              LeooVideoListJunPro.leooIndexJunPro = currentPage;
              eventBus.fire(LeooVideoPlayEventJunPro(currentPage));
            }
          }
          return false;
        },
        child: SmartRefresher(
          controller: _refreshController,
          header: const ClassicHeader(),
          footer: const ClassicFooter(),
          enablePullUp:
              videoList.length * 3 >= LeooAppConfigJunPro.leooPageSizeJunPro,
          onRefresh: () {
            page = 1;
            getList();
          },
          onLoading: () {
            page++;
            getList();
          },
          child: CustomScrollView(
            physics: const PageScrollPhysics(),
            controller: _pageController,
            slivers: <Widget>[
              SliverFillViewport(
                delegate:
                    SliverChildListDelegate(videoList.asMap().keys.map((index) {
                  return LeooVideoPlayJunPro(
                    index,
                    videoList[index],
                    play: index == LeooVideoListJunPro.leooIndexJunPro,
                    mine: widget.type == 3,
                  );
                }).toList()),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
